# OTRecod.jl

[Regularized optimal transport of covariates and outcomes in data recoding](https://hal.archives-ouvertes.fr/hal-02123109/file/OTRecoding.pdf), Garès, Valérie and Omer, Jérémy, 2019.

## Installation

All tests will run on the long-term support version of Julia Language (julia 1.0.5) which can be downloaded from https://julialang.org/downloads/#long-term_support_lts_release_v105_sep_9_2019

Dwonload and run the executable:
```cmd
> cd /path/to/julia/dir/
> ./bin/julia
```

You will then need to add every required packages after switching to Package mode in Julia:
```julia
julia>] # switch to pkg> mode
pkg> add JuMP
pkg> add Clp
pkg> add Distributions
pkg> add MultivariateStats
pkg> add PDMats
pkg> add Statistics
pkg> add Distances
pkg> add DataFrames
```

To run the code, navigate to the `/src` directory of `OTRecod.jl`:
```julia
julia> cd("/path/to/OTRecod.jl/src")
```

To test solution methods, simulate data as described in the manuscript. For faster tests, we simulate only 10 datasets taken from scenario Sref:
```julia
julia> include("simulateData.jl")
julia> simulateSref(10)
```
The data files are written in "/path/to/OTRecod.jl/data/Sref". Every scenario described in the manuscript can be created likewise. Please refer to `simulatData.jl`.

Now, we can include the main file and run the four methods on Sref scenario:
```julia
julia> include("OTRecod.jl")
julia> run_directory("../data/Sref/", :group, "../outfiles/Sref-outcome.out", 0.0, 0.0)
julia> run_directory("../data/Sref/", :group, "../outfiles/Sref-R-outcome.out", 0.4, 0.0)
julia> run_directory("../data/Sref/", :joint, "../outfiles/Sref-joint.out", 0.0, 0.0)
julia> run_directory("../data/Sref/", :joint, "../outfiles/Sref-R-joint.out", 0.4, 0.1)
```
The results are written as .out files in the "/outfiles" directory. In the output files, the average error is reported in the eDistravg column. 

For a more general understanding of the main function, please refer to the following documentation:
```julia
run_directory(path, method; outname="result.out",
                              maxrelax=0.0,
                              lambda_reg=0.0,
                              nbfiles=0,
                              norme=0,
                              percent_closest=0.2)

  Run one given method on a given number of data files of a given directory. The data files must be the only files with
  extension ".txt" in the directory.

 - `path`   : name of the directory
 - `method` : `:group` or `:joint`
 - `maxrelax`: maximum percentage of deviation from expected probability masses
 - `lambda_reg`: coefficient measuring the importance of the regularization term
 - `nbfiles`: number of files considered, 0 if all the data files are tested
 - `norme`  : 0, 1 or 2, norm used for distances in the space of covariates
 - `percent_closest`: percent of closest neighbors taken in the computation of the costs (both distance and regularization related)
 - `observed`: if nonempty, list of indices of the observed covariates; this allows to exclude some latent variables.
```

Copyright © 2020 Jeremy Omer <jeremy.omer@insa-rennes.fr>.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License version 3 as published by
the Free Software Foundation. See [LICENSE file](LICENSE).
